]> sigrok.org Git - libsigrok.git/blobdiff - session.c
sr: Fix some TODOs, improve comments/docs.
[libsigrok.git] / session.c
index 75a2cb353ba5a06b9dd6b1e4f87fae7ab612dd14..8687f4329917846c1b9d155c01f71650ba66d5d1 100644 (file)
--- a/session.c
+++ b/session.c
@@ -32,8 +32,8 @@ struct source {
        int fd;
        int events;
        int timeout;
-       sr_receive_data_callback cb;
-       void *user_data;
+       sr_receive_data_callback_t cb;
+       void *cb_data;
 };
 
 /* There can only be one session at a time. */
@@ -76,8 +76,8 @@ SR_API int sr_session_destroy(void)
                return SR_ERR_BUG;
        }
 
-       g_slist_free(session->devices);
-       session->devices = NULL;
+       g_slist_free(session->devs);
+       session->devs = NULL;
 
        /* TODO: Error checks needed? */
 
@@ -97,15 +97,15 @@ SR_API int sr_session_destroy(void)
  *
  * @return SR_OK upon success, SR_ERR_BUG if no session exists.
  */
-SR_API int sr_session_device_clear(void)
+SR_API int sr_session_dev_clear(void)
 {
        if (!session) {
                sr_err("session: %s: session was NULL", __func__);
                return SR_ERR_BUG;
        }
 
-       g_slist_free(session->devices);
-       session->devices = NULL;
+       g_slist_free(session->devs);
+       session->devs = NULL;
 
        return SR_OK;
 }
@@ -113,43 +113,42 @@ SR_API int sr_session_device_clear(void)
 /**
  * Add a device to the current session.
  *
* @param device The device to add to the current session. Must not be NULL.
*               Also, device->plugin and device->plugin->opendev must not
*               be NULL.
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments.
  */
-SR_API int sr_session_device_add(struct sr_device *device)
+SR_API int sr_session_dev_add(struct sr_dev *dev)
 {
        int ret;
 
-       if (!device) {
-               sr_err("session: %s: device was NULL", __func__);
+       if (!dev) {
+               sr_err("session: %s: dev was NULL", __func__);
                return SR_ERR_ARG;
        }
 
-       if (!device->plugin) {
-               sr_err("session: %s: device->plugin was NULL", __func__);
+       if (!dev->driver) {
+               sr_err("session: %s: dev->driver was NULL", __func__);
                return SR_ERR_ARG;
        }
 
-       if (!device->plugin->opendev) {
-               sr_err("session: %s: device->plugin->opendev was NULL",
+       if (!dev->driver->dev_open) {
+               sr_err("session: %s: dev->driver->dev_open was NULL",
                       __func__);
                return SR_ERR_ARG;
        }
 
        if (!session) {
                sr_err("session: %s: session was NULL", __func__);
-               return SR_ERR; /* TODO: SR_ERR_BUG? */
+               return SR_ERR_BUG;
        }
 
-       if ((ret = device->plugin->opendev(device->plugin_index)) != SR_OK) {
-               sr_err("session: %s: opendev failed (%d)", __func__, ret);
+       if ((ret = dev->driver->dev_open(dev->driver_index)) != SR_OK) {
+               sr_err("session: %s: dev_open failed (%d)", __func__, ret);
                return ret;
        }
 
-       session->devices = g_slist_append(session->devices, device);
+       session->devs = g_slist_append(session->devs, dev);
 
        return SR_OK;
 }
@@ -175,21 +174,25 @@ SR_API int sr_session_datafeed_callback_clear(void)
 /**
  * Add a datafeed callback to the current session.
  *
- * @param callback Function to call when a chunk of data is received.
+ * @param cb Function to call when a chunk of data is received.
+ *           Must not be NULL.
  *
  * @return SR_OK upon success, SR_ERR_BUG if no session exists.
  */
-SR_API int sr_session_datafeed_callback_add(sr_datafeed_callback callback)
+SR_API int sr_session_datafeed_callback_add(sr_datafeed_callback_t cb)
 {
        if (!session) {
                sr_err("session: %s: session was NULL", __func__);
                return SR_ERR_BUG;
        }
 
-       /* TODO: Is 'callback' allowed to be NULL? */
+       if (!cb) {
+               sr_err("session: %s: cb was NULL", __func__);
+               return SR_ERR_ARG;
+       }
 
        session->datafeed_callbacks =
-           g_slist_append(session->datafeed_callbacks, callback);
+           g_slist_append(session->datafeed_callbacks, cb);
 
        return SR_OK;
 }
@@ -234,7 +237,7 @@ static int sr_session_run_poll(void)
                                 * asked for that timeout.
                                 */
                                if (!sources[i].cb(fds[i].fd, fds[i].revents,
-                                                 sources[i].user_data))
+                                                 sources[i].cb_data))
                                        sr_session_source_remove(sources[i].fd);
                        }
                }
@@ -253,32 +256,32 @@ static int sr_session_run_poll(void)
  */
 SR_API int sr_session_start(void)
 {
-       struct sr_device *device;
+       struct sr_dev *dev;
        GSList *l;
        int ret;
 
        if (!session) {
                sr_err("session: %s: session was NULL; a session must be "
                       "created first, before starting it.", __func__);
-               return SR_ERR; /* TODO: SR_ERR_BUG? */
+               return SR_ERR_BUG;
        }
 
-       if (!session->devices) {
+       if (!session->devs) {
                /* TODO: Actually the case? */
-               sr_err("session: %s: session->devices was NULL; a session "
+               sr_err("session: %s: session->devs was NULL; a session "
                       "cannot be started without devices.", __func__);
-               return SR_ERR; /* TODO: SR_ERR_BUG? */
+               return SR_ERR_BUG;
        }
 
-       /* TODO: Check plugin_index validity? */
+       /* TODO: Check driver_index validity? */
 
        sr_info("session: starting");
 
-       for (l = session->devices; l; l = l->next) {
-               device = l->data;
-               /* TODO: Check for device != NULL. */
-               if ((ret = device->plugin->start_acquisition(
-                               device->plugin_index, device)) != SR_OK) {
+       for (l = session->devs; l; l = l->next) {
+               dev = l->data;
+               /* TODO: Check for dev != NULL. */
+               if ((ret = dev->driver->dev_acquisition_start(
+                               dev->driver_index, dev)) != SR_OK) {
                        sr_err("session: %s: could not start an acquisition "
                               "(%d)", __func__, ret);
                        break;
@@ -305,9 +308,9 @@ SR_API int sr_session_run(void)
                return SR_ERR_BUG;
        }
 
-       if (!session->devices) {
+       if (!session->devs) {
                /* TODO: Actually the case? */
-               sr_err("session: %s: session->devices was NULL; a session "
+               sr_err("session: %s: session->devs was NULL; a session "
                       "cannot be run without devices.", __func__);
                return SR_ERR_BUG;
        }
@@ -319,7 +322,7 @@ SR_API int sr_session_run(void)
        if (num_sources == 1 && sources[0].fd == -1) {
                /* Dummy source, freewheel over it. */
                while (session->running)
-                       sources[0].cb(-1, 0, sources[0].user_data);
+                       sources[0].cb(-1, 0, sources[0].cb_data);
        } else {
                /* Real sources, use g_poll() main loop. */
                sr_session_run_poll();
@@ -353,13 +356,13 @@ SR_API int sr_session_halt(void)
  * Stop the current session.
  *
  * The current session is stopped immediately, with all acquisition sessions
- * being stopped and hardware plugins cleaned up.
+ * being stopped and hardware drivers cleaned up.
  *
  * @return SR_OK upon success, SR_ERR_BUG if no session exists.
  */
 SR_API int sr_session_stop(void)
 {
-       struct sr_device *device;
+       struct sr_dev *dev;
        GSList *l;
 
        if (!session) {
@@ -370,14 +373,14 @@ SR_API int sr_session_stop(void)
        sr_info("session: stopping");
        session->running = FALSE;
 
-       for (l = session->devices; l; l = l->next) {
-               device = l->data;
-               /* Check for device != NULL. */
-               if (device->plugin) {
-                       if (device->plugin->stop_acquisition)
-                               device->plugin->stop_acquisition(device->plugin_index, device);
-                       if (device->plugin->cleanup)
-                               device->plugin->cleanup();
+       for (l = session->devs; l; l = l->next) {
+               dev = l->data;
+               /* Check for dev != NULL. */
+               if (dev->driver) {
+                       if (dev->driver->dev_acquisition_stop)
+                               dev->driver->dev_acquisition_stop(dev->driver_index, dev);
+                       if (dev->driver->cleanup)
+                               dev->driver->cleanup();
                }
        }
 
@@ -419,24 +422,24 @@ static void datafeed_dump(struct sr_datafeed_packet *packet)
  *
  * Hardware drivers use this to send a data packet to the frontend.
  *
- * @param device TODO.
- * @param packet TODO.
+ * @param dev TODO.
+ * @param packet The datafeed packet to send to the session bus.
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments.
  */
-SR_PRIV int sr_session_bus(struct sr_device *device,
-                          struct sr_datafeed_packet *packet)
+SR_PRIV int sr_session_send(struct sr_dev *dev,
+                           struct sr_datafeed_packet *packet)
 {
        GSList *l;
-       sr_datafeed_callback cb;
+       sr_datafeed_callback_t cb;
 
-       if (!device) {
-               sr_err("session: %s: device was NULL", __func__);
+       if (!dev) {
+               sr_err("session: %s: dev was NULL", __func__);
                return SR_ERR_ARG;
        }
 
-       if (!device->plugin) {
-               sr_err("session: %s: device->plugin was NULL", __func__);
+       if (!dev->driver) {
+               sr_err("session: %s: dev->driver was NULL", __func__);
                return SR_ERR_ARG;
        }
 
@@ -450,7 +453,7 @@ SR_PRIV int sr_session_bus(struct sr_device *device,
                        datafeed_dump(packet);
                cb = l->data;
                /* TODO: Check for cb != NULL. */
-               cb(device, packet);
+               cb(dev, packet);
        }
 
        return SR_OK;
@@ -464,23 +467,23 @@ SR_PRIV int sr_session_bus(struct sr_device *device,
  * @param fd TODO.
  * @param events TODO.
  * @param timeout TODO.
* @param callback TODO.
* @param user_data TODO.
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
  *         SR_ERR_MALLOC upon memory allocation errors.
  */
 SR_API int sr_session_source_add(int fd, int events, int timeout,
-               sr_receive_data_callback callback, void *user_data)
+               sr_receive_data_callback_t cb, void *cb_data)
 {
        struct source *new_sources, *s;
 
-       if (!callback) {
-               sr_err("session: %s: callback was NULL", __func__);
+       if (!cb) {
+               sr_err("session: %s: cb was NULL", __func__);
                return SR_ERR_ARG;
        }
 
/* Note: user_data can be NULL, that's not a bug. */
 
        new_sources = g_try_malloc0(sizeof(struct source) * (num_sources + 1));
        if (!new_sources) {
@@ -498,8 +501,8 @@ SR_API int sr_session_source_add(int fd, int events, int timeout,
        s->fd = fd;
        s->events = events;
        s->timeout = timeout;
-       s->cb = callback;
-       s->user_data = user_data;
+       s->cb = cb;
+       s->cb_data = cb_data;
        sources = new_sources;
 
        if (timeout != source_timeout && timeout > 0
@@ -527,7 +530,7 @@ SR_API int sr_session_source_remove(int fd)
 
        if (!sources) {
                sr_err("session: %s: sources was NULL", __func__);
-               return SR_ERR_BUG; /* TODO: Other? */
+               return SR_ERR_BUG;
        }
 
        /* TODO: Check if 'fd' valid. */
@@ -113,43 +113,42 @@ SR_API int sr_session_device_clear(void)
  * Add a device to the current session.
  *
- * @param device The device to add to the current session. Must not be NULL.
- *               Also, device->plugin and device->plugin->opendev must not
- *               be NULL.
+ * @param dev The device to add to the current session. Must not be NULL.
+ *            Also, dev->driver and dev->driver->dev_open must not be NULL.
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments.
@@ -464,23 +467,23 @@ SR_PRIV int sr_session_bus(struct sr_device *device,
  * @param events TODO.
  * @param timeout TODO.
- * @param callback TODO.
- * @param user_data TODO.
+ * @param cb Callback function to add. Must not be NULL.
+ * @param cb_data Data for the callback function. Can be NULL.
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
@@ -464,23 +467,23 @@ SR_PRIV int sr_session_bus(struct sr_device *device,
        }
 
-       /* Note: user_data can be NULL, that's not a bug. */
+       /* Note: cb_data can be NULL, that's not a bug. */
 
        new_sources = g_try_malloc0(sizeof(struct source) * (num_sources + 1));